@@ -20,7 +20,7 @@ logLik.gdina <- function (object, ...) {
     # number of parameters
     attr(out, "df") <- sum( object$Npars )
 	# extract number of observations
-    attr(out, "nobs") <- object$N
+    attr(out, "nobs") <- sum(object$N)
     class(out) <- "logLik"
     return(out)
 }
@@ -32,7 +32,7 @@ logLik.gdm <- function (object, ...) {
     # number of parameters
     attr(out, "df") <- sum( object$Npars )
 	# extract number of observations
-    attr(out, "nobs") <- object$N
+    attr(out, "nobs") <- sum(object$N)
     class(out) <- "logLik"
     return(out)
 }
@@ -45,7 +45,7 @@ logLik.mcdina <- function (object, ...) {
     # number of parameters
     attr(out, "df") <- sum( object$Npars )
 	# extract number of observations
-    attr(out, "nobs") <- object$I
+    attr(out, "nobs") <- sum(object$I)
     class(out) <- "logLik"
     return(out)
 }
@@ -58,7 +58,7 @@ logLik.slca <- function (object, ...) {
     # number of parameters
     attr(out, "df") <- sum( object$Npars )
 	# extract number of observations
-    attr(out, "nobs") <- object$N
+    attr(out, "nobs") <- sum(object$N)
     class(out) <- "logLik"
     return(out)
 }
